## 範例: 取得創世紀第1章第2節經文

```bash
> curl https://bible.fhl.net/api/qb.php?chap=1&sec=2&strong=0&gb=0&bid=1
{
    "status": "success",
    "record_count": 1,
    "v_name": null,
    "version": "nstrunv",
    "proc": 0,
    "record": [
        {
            "bid": 1,
            "engs": "Gen",
            "chineses": "創",
            "chap": 1,
            "sec": 1,
            "bible_text": "起初，神創造天地。"
        }
    ],
    "prev": {
        "bid": 1,
        "chineses": "創",
        "engs": "Gen",
        "chap": 1,
        "sec": 1
    },
    "next": {
        "bid": 1,
        "chineses": "創",
        "engs": "Gen",
        "chap": 1,
        "sec": 2
    }
}
```

參數

- bid 書卷編號 1-66
- strong 1 表示包含 strong number
- chap 章
- sec 節
- version 譯本

## 補充 version

根據您提供的 HTML 原始碼，解析 `id` 為 `oot1` 到 `oot5` 內的 `input` 標籤後，整理結果如下：

### 中文 (oot1)

* unv: 和合本
* rcuv: 和合本2010
* tcv95: 現代中文譯本1995版
* tcv2019: 現代中文譯本2019版
* wcb: 環球
* ncv: 新譯本
* recover: 恢復本
* ofm: 思高譯本
* lcc: 呂振中譯本
* cnet: CNET
* cumv: 官話和合本
* pmb: 北京官話譯本
* cuwv: 文理和合本
* orthdox: 俄羅斯正教譯本
* mormil: 神天聖書
* wdv: 委辦譯本
* ssewb: 施約瑟譯本
* marwb: 馬殊曼譯本
* cwmgbm: 四人小組譯本
* cwkfag: 郭實臘新舊遺詔聖書
* cogorw: 高連茨基聖詠經
* cbol: 原文直譯

### 英文 (oot2)

* esv: ESV
* kjv: KJV
* bbe: BBE
* web: WEB
* asv: ASV
* darby: Darby
* erv: ERV

### 原文與古譯本 (oot3)

* bhs: 原文
* lxx: 七十士譯本

### 台客語 (oot4)

* ttvhl2021: 現代台語漢字2021版
* ttvcl2021: 現代台語羅馬字2021版
* tghg: 聖經公會巴克禮台漢
* tte: 現代台語全羅2013版(詩、箴)
* ttvh: 現代台語漢字2013版(詩、箴)
* thv2e: 現代客語全羅
* thv12h: 現代客語漢字
* bklcl: 巴克禮
* bklhl: 巴克禮漢羅
* sgebklcl: 全民台語聖經全羅
* sgebklhl: 全民台語聖經漢羅

### 其他 (oot5)

* bunun: 布農語聖經
* tay: 泰雅爾語聖經
* sed: 賽德克族Tgdaya語聖經
* rukai: 魯凱語聖經
* amis2: 阿美語2019聖經(詩、箴)
* ams: 阿美語1997聖經
* tru: 太魯閣語聖經
* korean: 韓文聖經
* baru: 印尼聖經
* ind1958: 印尼舊聖經
* vietnamese: 越南聖經
* russian: 俄文聖經
* jp: 日文聖經
* tibet: 藏語聖經
* cvul: 武加大譯本
* nvul: 新武加大譯本


## 補充 bid

根據您提供的網頁內容，整理後的格式如下：

### 新舊約聖經

* 1: 創世記
* 2: 出埃及記
* 3: 利未記
* 4: 民數記
* 5: 申命記
* 6: 約書亞記
* 7: 士師記
* 8: 路得記
* 9: 撒母耳記上
* 10: 撒母耳記下
* 11: 列王紀上
* 12: 列王紀下
* 13: 歷代志上
* 14: 歷代志下
* 15: 以斯拉記
* 16: 尼希米記
* 17: 以斯帖記
* 18: 約伯記
* 19: 詩篇
* 20: 箴言
* 21: 傳道書
* 22: 雅歌
* 23: 以賽亞書
* 24: 耶利米書
* 25: 耶利米哀歌
* 26: 以西結書
* 27: 但以理書
* 28: 何西阿書
* 29: 約珥書
* 30: 阿摩司書
* 31: 俄巴底亞書
* 32: 約拿書
* 33: 彌迦書
* 34: 那鴻書
* 35: 哈巴谷書
* 36: 西番雅書
* 37: 哈該書
* 38: 撒迦利亞書
* 39: 馬拉基書
* 40: 馬太福音
* 41: 馬可福音
* 42: 路加福音
* 43: 約翰福音
* 44: 使徒行傳
* 45: 羅馬書
* 46: 哥林多前書
* 47: 哥林多後書
* 48: 加拉太書
* 49: 以弗所書
* 50: 腓立比書
* 51: 歌羅西書
* 52: 帖撒羅尼迦前書
* 53: 帖撒羅尼迦後書
* 54: 提摩太前書
* 55: 提摩太後書
* 56: 提多書
* 57: 腓利門書
* 58: 希伯來書
* 59: 雅各書
* 60: 彼得前書
* 61: 彼得後書
* 62: 約翰一書
* 63: 約翰二書
* 64: 約翰三書
* 65: 猶大書
* 66: 啟示錄

### 次經全書

* 101: 瑪喀比傳上卷
* 102: 瑪喀比傳下卷
* 103: 多比傳
* 104: 猶滴傳
* 105: 便西拉智訓
* 106: 所羅門智訓
* 107: 以斯拉續編上卷
* 108: 以斯拉續編下卷
* 109: 巴錄書
* 110: 耶利米書信
* 111: 瑪拿西禱言
* 112: 三童歌
* 113: 蘇撒拿傳
* 114: 比勒與大龍
* 115: 以斯帖補編

### 使徒教父著作

* 201: 革利免一書
* 202: 革利免二書
* 203: 伊格那丟致以弗所人書
* 204: 伊格那丟致馬內夏人書
* 205: 伊格那丟致他拉勒人書
* 206: 伊格那丟致羅馬人書
* 207: 伊格那丟致非拉鐵非人書
* 208: 伊格那丟致士每拿人書
* 209: 伊格那丟致坡旅甲書
* 210: 坡旅甲致腓立比人書
* 211: 坡旅甲殉道記
* 212: 十二使徒遺訓
* 213: 巴拿巴書信
* 214: 黑馬牧人書
* 215: 致丟格那妥書
* 216: 帕皮亞殘篇
* 217: 衆長老的傳統
